Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterBrowserControllerServer(s grpc.ServiceRegistrar, srv BrowserControllerServer)
- type BrowserControllerClient
- type BrowserControllerServer
- type BrowserController_DoClient
- type BrowserController_DoServer
- type Completed
- type DoReply
- func (*DoReply) Descriptor() ([]byte, []int)deprecated
- func (x *DoReply) GetAction() isDoReply_Action
- func (x *DoReply) GetCancel() string
- func (x *DoReply) GetNew() *NewReply
- func (*DoReply) ProtoMessage()
- func (x *DoReply) ProtoReflect() protoreflect.Message
- func (x *DoReply) Reset()
- func (x *DoReply) String() string
- type DoReply_Cancel
- type DoReply_New
- type DoRequest
- func (*DoRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DoRequest) GetAction() isDoRequest_Action
- func (x *DoRequest) GetCompleted() *Completed
- func (x *DoRequest) GetNew() *RegisterNew
- func (x *DoRequest) GetNotify() *NotifyActivity
- func (*DoRequest) ProtoMessage()
- func (x *DoRequest) ProtoReflect() protoreflect.Message
- func (x *DoRequest) Reset()
- func (x *DoRequest) String() string
- type DoRequest_Completed
- type DoRequest_New
- type DoRequest_Notify
- type NewReply
- func (*NewReply) Descriptor() ([]byte, []int)deprecated
- func (x *NewReply) GetCollectionRef() *v1.ConfigRef
- func (x *NewReply) GetCrawlExecutionId() string
- func (x *NewReply) GetJobExecutionId() string
- func (x *NewReply) GetReplacementScript() *v1.BrowserScript
- func (*NewReply) ProtoMessage()
- func (x *NewReply) ProtoReflect() protoreflect.Message
- func (x *NewReply) Reset()
- func (x *NewReply) String() string
- type NotifyActivity
- type NotifyActivity_Activity
- func (NotifyActivity_Activity) Descriptor() protoreflect.EnumDescriptor
- func (x NotifyActivity_Activity) Enum() *NotifyActivity_Activity
- func (NotifyActivity_Activity) EnumDescriptor() ([]byte, []int)deprecated
- func (x NotifyActivity_Activity) Number() protoreflect.EnumNumber
- func (x NotifyActivity_Activity) String() string
- func (NotifyActivity_Activity) Type() protoreflect.EnumType
- type RegisterNew
- func (*RegisterNew) Descriptor() ([]byte, []int)deprecated
- func (x *RegisterNew) GetCollectionRef() *v1.ConfigRef
- func (x *RegisterNew) GetCrawlExecutionId() string
- func (x *RegisterNew) GetJobExecutionId() string
- func (x *RegisterNew) GetMethod() string
- func (x *RegisterNew) GetProxyId() int32
- func (x *RegisterNew) GetRequestId() string
- func (x *RegisterNew) GetUri() string
- func (*RegisterNew) ProtoMessage()
- func (x *RegisterNew) ProtoReflect() protoreflect.Message
- func (x *RegisterNew) Reset()
- func (x *RegisterNew) String() string
- type UnimplementedBrowserControllerServer
- type UnsafeBrowserControllerServer
Constants ¶
const (
BrowserController_Do_FullMethodName = "/veidemann.api.browsercontroller.v1.BrowserController/do"
)
Variables ¶
var ( NotifyActivity_Activity_name = map[int32]string{ 0: "DATA_RECEIVED", 1: "ALL_DATA_RECEIVED", } NotifyActivity_Activity_value = map[string]int32{ "DATA_RECEIVED": 0, "ALL_DATA_RECEIVED": 1, } )
Enum value maps for NotifyActivity_Activity.
var BrowserController_ServiceDesc = grpc.ServiceDesc{ ServiceName: "veidemann.api.browsercontroller.v1.BrowserController", HandlerType: (*BrowserControllerServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "do", Handler: _BrowserController_Do_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "browsercontroller/v1/browsercontroller.proto", }
BrowserController_ServiceDesc is the grpc.ServiceDesc for BrowserController service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_browsercontroller_v1_browsercontroller_proto protoreflect.FileDescriptor
Functions ¶
func RegisterBrowserControllerServer ¶
func RegisterBrowserControllerServer(s grpc.ServiceRegistrar, srv BrowserControllerServer)
Types ¶
type BrowserControllerClient ¶
type BrowserControllerClient interface {
Do(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[DoRequest, DoReply], error)
}
BrowserControllerClient is the client API for BrowserController service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Service for used by recorder proxy to comunicate with browser controller.
func NewBrowserControllerClient ¶
func NewBrowserControllerClient(cc grpc.ClientConnInterface) BrowserControllerClient
type BrowserControllerServer ¶
type BrowserControllerServer interface {
Do(grpc.BidiStreamingServer[DoRequest, DoReply]) error
}
BrowserControllerServer is the server API for BrowserController service. All implementations should embed UnimplementedBrowserControllerServer for forward compatibility.
Service for used by recorder proxy to comunicate with browser controller.
type BrowserController_DoClient ¶
type BrowserController_DoClient = grpc.BidiStreamingClient[DoRequest, DoReply]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type BrowserController_DoServer ¶
type BrowserController_DoServer = grpc.BidiStreamingServer[DoRequest, DoReply]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Completed ¶
type Completed struct {
CrawlLog *v11.CrawlLog `protobuf:"bytes,1,opt,name=crawl_log,json=crawlLog,proto3" json:"crawl_log,omitempty"`
Cached bool `protobuf:"varint,2,opt,name=cached,proto3" json:"cached,omitempty"`
// contains filtered or unexported fields
}
func (*Completed) Descriptor
deprecated
func (*Completed) GetCrawlLog ¶
func (*Completed) ProtoMessage ¶
func (*Completed) ProtoMessage()
func (*Completed) ProtoReflect ¶
func (x *Completed) ProtoReflect() protoreflect.Message
type DoReply ¶
type DoReply struct {
// Types that are valid to be assigned to Action:
//
// *DoReply_New
// *DoReply_Cancel
Action isDoReply_Action `protobuf_oneof:"action"`
// contains filtered or unexported fields
}
func (*DoReply) Descriptor
deprecated
func (*DoReply) ProtoMessage ¶
func (*DoReply) ProtoMessage()
func (*DoReply) ProtoReflect ¶
func (x *DoReply) ProtoReflect() protoreflect.Message
type DoReply_Cancel ¶
type DoReply_Cancel struct {
Cancel string `protobuf:"bytes,4,opt,name=cancel,proto3,oneof"` // Roll back the request. The message should contain the reason for canceling the request.
}
type DoReply_New ¶
type DoReply_New struct {
New *NewReply `protobuf:"bytes,1,opt,name=new,proto3,oneof"`
}
type DoRequest ¶
type DoRequest struct {
// Types that are valid to be assigned to Action:
//
// *DoRequest_New
// *DoRequest_Notify
// *DoRequest_Completed
Action isDoRequest_Action `protobuf_oneof:"action"`
// contains filtered or unexported fields
}
func (*DoRequest) Descriptor
deprecated
func (*DoRequest) GetCompleted ¶
func (*DoRequest) GetNew ¶
func (x *DoRequest) GetNew() *RegisterNew
func (*DoRequest) GetNotify ¶
func (x *DoRequest) GetNotify() *NotifyActivity
func (*DoRequest) ProtoMessage ¶
func (*DoRequest) ProtoMessage()
func (*DoRequest) ProtoReflect ¶
func (x *DoRequest) ProtoReflect() protoreflect.Message
type DoRequest_Completed ¶
type DoRequest_Completed struct {
Completed *Completed `protobuf:"bytes,3,opt,name=completed,proto3,oneof"`
}
type DoRequest_New ¶
type DoRequest_New struct {
New *RegisterNew `protobuf:"bytes,1,opt,name=new,proto3,oneof"`
}
type DoRequest_Notify ¶
type DoRequest_Notify struct {
Notify *NotifyActivity `protobuf:"bytes,2,opt,name=notify,proto3,oneof"`
}
type NewReply ¶
type NewReply struct {
CrawlExecutionId string `protobuf:"bytes,1,opt,name=crawl_execution_id,json=crawlExecutionId,proto3" json:"crawl_execution_id,omitempty"`
JobExecutionId string `protobuf:"bytes,2,opt,name=job_execution_id,json=jobExecutionId,proto3" json:"job_execution_id,omitempty"`
CollectionRef *v1.ConfigRef `protobuf:"bytes,4,opt,name=collection_ref,json=collectionRef,proto3" json:"collection_ref,omitempty"`
ReplacementScript *v1.BrowserScript `protobuf:"bytes,5,opt,name=replacement_script,json=replacementScript,proto3" json:"replacement_script,omitempty"`
// contains filtered or unexported fields
}
func (*NewReply) Descriptor
deprecated
func (*NewReply) GetCollectionRef ¶
func (*NewReply) GetCrawlExecutionId ¶
func (*NewReply) GetJobExecutionId ¶
func (*NewReply) GetReplacementScript ¶
func (x *NewReply) GetReplacementScript() *v1.BrowserScript
func (*NewReply) ProtoMessage ¶
func (*NewReply) ProtoMessage()
func (*NewReply) ProtoReflect ¶
func (x *NewReply) ProtoReflect() protoreflect.Message
type NotifyActivity ¶
type NotifyActivity struct {
Activity NotifyActivity_Activity `` /* 134-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*NotifyActivity) Descriptor
deprecated
func (*NotifyActivity) Descriptor() ([]byte, []int)
Deprecated: Use NotifyActivity.ProtoReflect.Descriptor instead.
func (*NotifyActivity) GetActivity ¶
func (x *NotifyActivity) GetActivity() NotifyActivity_Activity
func (*NotifyActivity) ProtoMessage ¶
func (*NotifyActivity) ProtoMessage()
func (*NotifyActivity) ProtoReflect ¶
func (x *NotifyActivity) ProtoReflect() protoreflect.Message
func (*NotifyActivity) Reset ¶
func (x *NotifyActivity) Reset()
func (*NotifyActivity) String ¶
func (x *NotifyActivity) String() string
type NotifyActivity_Activity ¶
type NotifyActivity_Activity int32
const ( NotifyActivity_DATA_RECEIVED NotifyActivity_Activity = 0 NotifyActivity_ALL_DATA_RECEIVED NotifyActivity_Activity = 1 )
func (NotifyActivity_Activity) Descriptor ¶
func (NotifyActivity_Activity) Descriptor() protoreflect.EnumDescriptor
func (NotifyActivity_Activity) Enum ¶
func (x NotifyActivity_Activity) Enum() *NotifyActivity_Activity
func (NotifyActivity_Activity) EnumDescriptor
deprecated
func (NotifyActivity_Activity) EnumDescriptor() ([]byte, []int)
Deprecated: Use NotifyActivity_Activity.Descriptor instead.
func (NotifyActivity_Activity) Number ¶
func (x NotifyActivity_Activity) Number() protoreflect.EnumNumber
func (NotifyActivity_Activity) String ¶
func (x NotifyActivity_Activity) String() string
func (NotifyActivity_Activity) Type ¶
func (NotifyActivity_Activity) Type() protoreflect.EnumType
type RegisterNew ¶
type RegisterNew struct {
ProxyId int32 `protobuf:"varint,1,opt,name=proxy_id,json=proxyId,proto3" json:"proxy_id,omitempty"`
Uri string `protobuf:"bytes,2,opt,name=uri,proto3" json:"uri,omitempty"`
CrawlExecutionId string `protobuf:"bytes,3,opt,name=crawl_execution_id,json=crawlExecutionId,proto3" json:"crawl_execution_id,omitempty"`
JobExecutionId string `protobuf:"bytes,4,opt,name=job_execution_id,json=jobExecutionId,proto3" json:"job_execution_id,omitempty"`
CollectionRef *v1.ConfigRef `protobuf:"bytes,5,opt,name=collection_ref,json=collectionRef,proto3" json:"collection_ref,omitempty"`
Method string `protobuf:"bytes,6,opt,name=method,proto3" json:"method,omitempty"` // The HTTP method (GET, POST, HEAD, ...)
RequestId string `protobuf:"bytes,7,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"` // The browsers internal request id.
// contains filtered or unexported fields
}
func (*RegisterNew) Descriptor
deprecated
func (*RegisterNew) Descriptor() ([]byte, []int)
Deprecated: Use RegisterNew.ProtoReflect.Descriptor instead.
func (*RegisterNew) GetCollectionRef ¶
func (x *RegisterNew) GetCollectionRef() *v1.ConfigRef
func (*RegisterNew) GetCrawlExecutionId ¶
func (x *RegisterNew) GetCrawlExecutionId() string
func (*RegisterNew) GetJobExecutionId ¶
func (x *RegisterNew) GetJobExecutionId() string
func (*RegisterNew) GetMethod ¶
func (x *RegisterNew) GetMethod() string
func (*RegisterNew) GetProxyId ¶
func (x *RegisterNew) GetProxyId() int32
func (*RegisterNew) GetRequestId ¶
func (x *RegisterNew) GetRequestId() string
func (*RegisterNew) GetUri ¶
func (x *RegisterNew) GetUri() string
func (*RegisterNew) ProtoMessage ¶
func (*RegisterNew) ProtoMessage()
func (*RegisterNew) ProtoReflect ¶
func (x *RegisterNew) ProtoReflect() protoreflect.Message
func (*RegisterNew) Reset ¶
func (x *RegisterNew) Reset()
func (*RegisterNew) String ¶
func (x *RegisterNew) String() string
type UnimplementedBrowserControllerServer ¶
type UnimplementedBrowserControllerServer struct{}
UnimplementedBrowserControllerServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
type UnsafeBrowserControllerServer ¶
type UnsafeBrowserControllerServer interface {
// contains filtered or unexported methods
}
UnsafeBrowserControllerServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BrowserControllerServer will result in compilation errors.