Documentation
¶
Index ¶
Constants ¶
const ServerName = "recorderproxy.invalid"
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Identity ¶
type Identity struct {
// contains filtered or unexported fields
}
Identity is an immutable TLS server identity shared by proxy listeners.
func LoadIdentity ¶
LoadIdentity loads and validates a non-expired TLS server identity.
func ParseIdentity ¶
ParseIdentity validates a PEM-encoded TLS server identity.
func (*Identity) Certificate ¶
func (i *Identity) Certificate() *x509.Certificate
Certificate returns the parsed public certificate for identity checks.
func (*Identity) TLSCertificate ¶
func (i *Identity) TLSCertificate() *tls.Certificate
TLSCertificate returns the immutable key pair used by TLS listeners.
Click to show internal directories.
Click to hide internal directories.